package
Version:
v0.2.12
Opens a new window with list of versions in this module.
Published: Oct 30, 2021
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Compare[T any] interface {
Cmp(T, T) bool
}
func (g *Greater[T]) Cmp(lhs T, rhs T) bool
func (l *Less[T]) Cmp(lhs T, rhs T) bool
type Pair[T1 any, T2 any] struct {
First T1
Second T2
}
func MakePair[T1 any, T2 any](first T1, second T2) *Pair[T1, T2]
Source Files
¶
Click to show internal directories.
Click to hide internal directories.