Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Queue ¶
type Queue[T any] struct { // contains filtered or unexported fields }
Queue is a container adapter that gives the programmer the functionality of a queue - specifically, a FIFO (first-in, first-out) data structure.
func (*Queue[T]) Back ¶
func (q *Queue[T]) Back() T
Back returns value of the last element in Queue Complexity O(1)
func (*Queue[T]) Front ¶
func (q *Queue[T]) Front() T
Front returns value of the first element in Queue Complexity O(1)
func (*Queue[T]) Pop ¶
func (q *Queue[T]) Pop() T
Pop removes and returns first element of Queue Complexity O(1)
Click to show internal directories.
Click to hide internal directories.