Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Vector ¶
type Vector[T any] struct { // contains filtered or unexported fields }
func (*Vector[T]) At ¶
At returns a reference to the element at specified location pos, with bounds checking. If pos is not within the range of the container, a panic is thrown. Complexity - O(1).
func (*Vector[T]) Back ¶
func (v *Vector[T]) Back() T
Back returns a reference to the last element in the container. Calling Back on an empty container causes undefined behavior. Complexity - O(1).
func (*Vector[T]) Capacity ¶
Capacity returns the number of elements that the container has currently allocated space for. Complexity - O(1).
func (*Vector[T]) Front ¶
func (v *Vector[T]) Front() T
Front returns a reference to the first element in the container. Calling Front on an empty container is undefined. Complexity - O(1).
Click to show internal directories.
Click to hide internal directories.